summaryrefslogtreecommitdiffstats
path: root/kregexpeditor/textwidget.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:17 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:17 -0600
commit955e20356d63ed405198c8143617a8a0ca8bfc02 (patch)
tree9a9ab22c86d212a5655014ad752e96b04c0c86a9 /kregexpeditor/textwidget.cpp
parentbf280726d5d22f33d33e4f9e771220c725249407 (diff)
downloadtdeutils-955e20356d63ed405198c8143617a8a0ca8bfc02.tar.gz
tdeutils-955e20356d63ed405198c8143617a8a0ca8bfc02.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit bf280726d5d22f33d33e4f9e771220c725249407.
Diffstat (limited to 'kregexpeditor/textwidget.cpp')
-rw-r--r--kregexpeditor/textwidget.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kregexpeditor/textwidget.cpp b/kregexpeditor/textwidget.cpp
index d2f7549..99a77e1 100644
--- a/kregexpeditor/textwidget.cpp
+++ b/kregexpeditor/textwidget.cpp
@@ -22,7 +22,7 @@
#include "textwidget.h"
#include "textregexp.h"
#include "selectablelineedit.h"
-#include <layout.h>
+#include <tqlayout.h>
TextWidget::TextWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name)
@@ -56,19 +56,19 @@ void TextWidget::init( const TQString& txt )
void TextWidget::slotUpdate()
{
// I need to force the parent to repaint, as the size change of this
// widget may not be enough for the parent to change size, and in that
// case the parent would not repaint, and the text widget would not be
// resized.
TQWidget *p = TQT_TQWIDGET(parent());
if (p)
- p->repaint();
+ p->tqrepaint();
_editorWindow->updateContent( this );
}
-TQSize TextWidget::sizeHint() const
+TQSize TextWidget::tqsizeHint() const
{
- return _edit->sizeHint();
+ return _edit->tqsizeHint();
}
void TextWidget::paintEvent( TQPaintEvent *e)
@@ -56,19 +56,19 @@ void TextWidget::init( const TQString& txt )
void TextWidget::slotUpdate()
{
- // I need to force the parent to repaint, as the size change of this
+ // I need to force the parent to tqrepaint, as the size change of this
// widget may not be enough for the parent to change size, and in that
@@ -56,19 +56,19 @@ void TextWidget::init( const TQString& txt )
// widget may not be enough for the parent to change size, and in that
- // case the parent would not repaint, and the text widget would not be
+ // case the parent would not tqrepaint, and the text widget would not be
// resized.
TQWidget *p = TQT_TQWIDGET(parent());